// Type definitions for Talk2Me application

export interface TranscriptionResponse {
  success: boolean;
  text?: string;
  error?: string;
  detected_language?: string;
}

export interface TranslationResponse {
  success: boolean;
  translation?: string;
  error?: string;
}

export interface TTSResponse {
  success: boolean;
  audio_url?: string;
  error?: string;
}

export interface TTSServerStatus {
  status: 'online' | 'error' | 'auth_error';
  message: string;
  url: string;
  code?: number;
}

export interface TTSConfigUpdate {
  server_url?: string;
  api_key?: string;
}

export interface TTSConfigResponse {
  success: boolean;
  message?: string;
  url?: string;
  error?: string;
}

export interface TranslationRequest {
  text: string;
  source_lang: string;
  target_lang: string;
}

export interface TTSRequest {
  text: string;
  language: string;
}

export interface PushPublicKeyResponse {
  publicKey: string;
}

export interface IndexedDBRecord {
  timestamp: string;
}

export interface TranscriptionRecord extends IndexedDBRecord {
  text: string;
  language: string;
}

export interface TranslationRecord extends IndexedDBRecord {
  sourceText: string;
  sourceLanguage: string;
  targetText: string;
  targetLanguage: string;
}

export interface TranslationCacheEntry {
  key: string;
  sourceText: string;
  sourceLanguage: string;
  targetText: string;
  targetLanguage: string;
  timestamp: number;
  accessCount: number;
  lastAccessed: number;
}

export interface CacheStats {
  totalEntries: number;
  totalSize: number;
  oldestEntry: number;
  newestEntry: number;
}

// Service Worker types
export interface PeriodicSyncManager {
  register(tag: string, options?: { minInterval: number }): Promise<void>;
}

export interface ServiceWorkerRegistrationExtended extends ServiceWorkerRegistration {
  periodicSync?: PeriodicSyncManager;
}

// Extend window interface for PWA features
declare global {
  interface Window {
    deferredPrompt?: BeforeInstallPromptEvent;
  }
}

export interface BeforeInstallPromptEvent extends Event {
  prompt(): Promise<void>;
  userChoice: Promise<{ outcome: 'accepted' | 'dismissed' }>;
}