// PWA Update Helper
// This script helps force PWA updates on clients

// Force service worker update
if ('serviceWorker' in navigator) {
    navigator.serviceWorker.getRegistrations().then(function(registrations) {
        for(let registration of registrations) {
            registration.unregister().then(function() {
                console.log('Service worker unregistered');
            });
        }
    });
    
    // Re-register after a short delay
    setTimeout(function() {
        navigator.serviceWorker.register('/service-worker.js')
            .then(function(registration) {
                console.log('Service worker re-registered');
                registration.update();
            });
    }, 1000);
}

// Clear all caches
if ('caches' in window) {
    caches.keys().then(function(names) {
        for (let name of names) {
            caches.delete(name);
            console.log('Cache cleared:', name);
        }
    });
}

// Reload manifest
var link = document.querySelector('link[rel="manifest"]');
if (link) {
    link.href = link.href + '?v=' + Date.now();
    console.log('Manifest reloaded');
}

console.log('PWA update complete. Please reload the page.');